# PySysMetrics

A lightweight Python CLI tool to monitor CPU and GPU memory usage by active Python processes.

## Features

- Monitor memory used by Python scripts.
- Display running GPU Python processes with memory usage.
- Auto-refreshes in a given interval.

## Installation

```bash
pip install pysysmetrics